@@ -44,7 +44,7 @@ class GBMFitter:
         self.metrics = metrics
 
         if isinstance(cv_strategy, list):
-            self.cv = _Folds(list)
+            self.cv = _Folds(cv_strategy)
         else:
             self.cv = cv_strategy
 
